chemcoord.zmat\_functions.DummyManipulation
===========================================

.. currentmodule:: chemcoord.zmat_functions

.. autoclass:: DummyManipulation

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DummyManipulation.__init__
   
   

   
   
   